@@ -56,7 +56,7 @@ Canvas_PrintLayout::Canvas_PrintLayout()
 
   m_items_group = Goocanvas::Group::create();
   //m_items_group->signal_button_press_event().connect( sigc::ptr_fun(&on_group_button_press_event), false );
-  //TODO: How does this have any effect?: m_items_group->property_pointer_events() = Goocanvas::CANVAS_EVENTS_NONE;
+  //TODO: How does this have any effect?: m_items_group->property_pointer_events() = Goocanvas::EVENTS_NONE;
   Glib::RefPtr<Goocanvas::Item> root = get_root_item();
   if(root)
     root->add_child(m_items_group);
@@ -785,7 +785,7 @@ guint Canvas_PrintLayout::get_zoom_percent() const
 
 void Canvas_PrintLayout::hide_page_bounds()
 {
-  m_bounds_group->property_visibility() = Goocanvas::CANVAS_ITEM_HIDDEN;
+  m_bounds_group->property_visibility() = Goocanvas::ITEM_HIDDEN;
 }
 
 void Canvas_PrintLayout::set_grid_gap(double gap)
@@ -815,17 +815,14 @@ Glib::RefPtr<Goocanvas::Item> Canvas_PrintLayout::get_canvas_table_cell_child(co
     if(!child)
       continue;
 
-    Glib::Value<int> column_value;
-    column_value.init( Glib::Value<int>::value_type() );
+    int column_value = 0;
     table->get_child_property(child, "column", column_value);
-
-    Glib::Value<int> row_value;
-    row_value.init( Glib::Value<int>::value_type() );
+    int row_value = 0;
     table->get_child_property(child, "row", row_value);
        
     //This assumes that all items occupy only one cell:
-    if( (column_value.get() == col) &&
-        (row_value.get() == row) )
+    if( (column_value == col) &&
+        (row_value == row) )
     {
       return child;
     }
